package com.bonus.zlpt.order.service;

import java.util.List;
import com.bonus.zlpt.common.core.domain.order.OrderInfo;
import com.bonus.zlpt.common.core.domain.order.vo.OrderInfoVo;

/**
 * 订单信息Service接口
 * 
 * @author xsheng
 * @date 2023-12-01
 */
public interface IOrderInfoService 
{
    /**
     * 查询订单信息
     * 
     * @param orderId 订单信息主键
     * @return 订单信息
     */
    public OrderInfoVo selectOrderInfoByOrderId(Long orderId);

    /**
     * 查询订单信息列表
     * 
     * @param orderInfo 订单信息
     * @return 订单信息集合
     */
    public List<OrderInfoVo> selectOrderInfoList(OrderInfoVo orderInfo);

    /**
     * 新增订单信息
     * 
     * @param orderInfo 订单信息
     * @return 结果
     */
    public int insertOrderInfo(OrderInfoVo orderInfo);

    /**
     * 修改订单信息
     * 
     * @param orderInfo 订单信息
     * @return 结果
     */
    public int updateOrderInfo(OrderInfoVo orderInfo);

    public int rejectOrderInfo(OrderInfoVo orderInfo);

    /**
     * 批量删除订单信息
     * 
     * @param orderIds 需要删除的订单信息主键集合
     * @return 结果
     */
    public int deleteOrderInfoByOrderIds(Long[] orderIds);

    /**
     * 删除订单信息信息
     * 
     * @param orderId 订单信息主键
     * @return 结果
     */
    public int deleteOrderInfoByOrderId(Long orderId);

    public long count();
}
